Eyes Robot Framework SDK
========================

Applitools Eyes SDK For Robot Framework

Installation
------------

Install the eyes-robot SDK:

::

    pip install eyes-robotframework

Docs
-----

1. `Complete guide to using Eyes with the Robot framework <https://applitools.com/docs/api/robot/robot-eyes-library.html>`_
2. `Keyword documentation <https://applitools.github.io/eyes.sdk.python/eyes_robotframework/keywords.html>`_.
3. `Configuration file overview <https://applitools.com/docs/api/robot/robot-configuration-file.html>`_

Robot Framework SDK example repo: https://github.com/applitools/robotframework-quickstart

Robot Framework autocompletion plugins
--------------------------------------

**IntelliJ (PyCharm and friends)** *Recommended - most full support*
https://plugins.jetbrains.com/plugin/17424-intellibot-patched

**RobotFramework language server based** (`pip install robotframework-lsp`)
These plugins have issues with auto-completion of check settings keywords.


**IntelliJ (PyCharm and friends)**

https://plugins.jetbrains.com/plugin/16086-robot-framework-language-server

**VSCode**

https://marketplace.visualstudio.com/items?itemName=robocorp.robotframework-lsp
